@@ -614,9 +614,8 @@ where
 mod test {
   use crate::pg::PgLinkStore;
   use crate::test::TestApi;
-  use chrono::{TimeZone, Utc};
   use etwin_core::clock::VirtualClock;
-  use etwin_core::core::Secret;
+  use etwin_core::core::{Instant, Secret};
   use etwin_core::dinoparc::DinoparcStore;
   use etwin_core::hammerfest::HammerfestStore;
   use etwin_core::link::LinkStore;
@@ -668,7 +667,7 @@ mod test {
       .unwrap();
     let database = Arc::new(database);
 
-    let clock = Arc::new(VirtualClock::new(Utc.timestamp(1607531946, 0)));
+    let clock = Arc::new(VirtualClock::new(Instant::ymd_hms(2020, 1, 1, 0, 0, 0)));
     let uuid_generator = Arc::new(Uuid4Generator);
     let dinoparc_store: Arc<dyn DinoparcStore> = Arc::new(
       PgDinoparcStore::new(Arc::clone(&clock), Arc::clone(&database), Arc::clone(&uuid_generator))
